/*
 * Copyright (c) 2020 Texas Instruments Incorporated - http://www.ti.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef BOARD_H
#define BOARD_H

//*****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//*****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

//
// Included Files
//

#include "driverlib.h"
#include "device.h"

//*****************************************************************************
//
// PinMux Configurations
//
//*****************************************************************************

//
// ANALOG -> PFC_MOTORS_EMI Pinmux
//

//
// EPWM1 -> myEPWM0 Pinmux
//
//
// EPWM1_A - GPIO Settings
//
#define GPIO_PIN_EPWM1_A 0
#define myEPWM0_EPWMA_GPIO 0
#define myEPWM0_EPWMA_PIN_CONFIG GPIO_0_EPWM1_A
//
// EPWM1_B - GPIO Settings
//
#define GPIO_PIN_EPWM1_B 1
#define myEPWM0_EPWMB_GPIO 1
#define myEPWM0_EPWMB_PIN_CONFIG GPIO_1_EPWM1_B

//*****************************************************************************
//
// ADC Configurations
//
//*****************************************************************************
#define myADCA_BASE ADCC_BASE
#define myADCA_RESULT_BASE ADCCRESULT_BASE
#define myADCA_SOC0 ADC_SOC_NUMBER0
#define myADCA_FORCE_SOC0 ADC_FORCE_SOC0
#define myADCA_SAMPLE_WINDOW_SOC0 166.66666666666669
#define myADCA_TRIGGER_SOURCE_SOC0 ADC_TRIGGER_EPWM1_SOCA
#define myADCA_CHANNEL_SOC0 ADC_CH_ADCIN18
#define myADCA_SOC1 ADC_SOC_NUMBER1
#define myADCA_FORCE_SOC1 ADC_FORCE_SOC1
#define myADCA_SAMPLE_WINDOW_SOC1 166.66666666666669
#define myADCA_TRIGGER_SOURCE_SOC1 ADC_TRIGGER_EPWM1_SOCA
#define myADCA_CHANNEL_SOC1 ADC_CH_ADCIN6
#define myADCA_SOC2 ADC_SOC_NUMBER2
#define myADCA_FORCE_SOC2 ADC_FORCE_SOC2
#define myADCA_SAMPLE_WINDOW_SOC2 166.66666666666669
#define myADCA_TRIGGER_SOURCE_SOC2 ADC_TRIGGER_EPWM1_SOCA
#define myADCA_CHANNEL_SOC2 ADC_CH_ADCIN7
#define myADCA_IU_M1 ADC_SOC_NUMBER4
#define myADCA_FORCE_IU_M1 ADC_FORCE_SOC4
#define myADCA_SAMPLE_WINDOW_IU_M1 125.00000000000001
#define myADCA_TRIGGER_SOURCE_IU_M1 ADC_TRIGGER_EPWM1_SOCA
#define myADCA_CHANNEL_IU_M1 ADC_CH_ADCIN15
#define myADCA_IV_M1 ADC_SOC_NUMBER5
#define myADCA_FORCE_IV_M1 ADC_FORCE_SOC5
#define myADCA_SAMPLE_WINDOW_IV_M1 125.00000000000001
#define myADCA_TRIGGER_SOURCE_IV_M1 ADC_TRIGGER_SW_ONLY
#define myADCA_CHANNEL_IV_M1 ADC_CH_ADCIN1
#define myADCA_IW_M1 ADC_SOC_NUMBER6
#define myADCA_FORCE_IW_M1 ADC_FORCE_SOC6
#define myADCA_SAMPLE_WINDOW_IW_M1 125.00000000000001
#define myADCA_TRIGGER_SOURCE_IW_M1 ADC_TRIGGER_SW_ONLY
#define myADCA_CHANNEL_IW_M1 ADC_CH_ADCIN3
void myADCA_init();

#define PFC_MTRS_BASE ADCA_BASE
#define PFC_MTRS_RESULT_BASE ADCARESULT_BASE
#define PFC_MTRS_IAC1 ADC_SOC_NUMBER0
#define PFC_MTRS_FORCE_IAC1 ADC_FORCE_SOC0
#define PFC_MTRS_SAMPLE_WINDOW_IAC1 116.66666666666667
#define PFC_MTRS_TRIGGER_SOURCE_IAC1 ADC_TRIGGER_EPWM2_SOCA
#define PFC_MTRS_CHANNEL_IAC1 ADC_CH_ADCIN9
#define PFC_MTRS_VAC1 ADC_SOC_NUMBER1
#define PFC_MTRS_FORCE_VAC1 ADC_FORCE_SOC1
#define PFC_MTRS_SAMPLE_WINDOW_VAC1 166.66666666666669
#define PFC_MTRS_TRIGGER_SOURCE_VAC1 ADC_TRIGGER_EPWM7_SOCA
#define PFC_MTRS_CHANNEL_VAC1 ADC_CH_ADCIN10
#define PFC_MTRS_VDC1 ADC_SOC_NUMBER2
#define PFC_MTRS_FORCE_VDC1 ADC_FORCE_SOC2
#define PFC_MTRS_SAMPLE_WINDOW_VDC1 166.66666666666669
#define PFC_MTRS_TRIGGER_SOURCE_VDC1 ADC_TRIGGER_EPWM7_SOCA
#define PFC_MTRS_CHANNEL_VDC1 ADC_CH_ADCIN4
#define PFC_MTRS_PPB1 ADC_PPB_NUMBER1
#define PFC_MTRS_SOC_PPB1 ADC_SOC_NUMBER0
#define PFC_MTRS_PPB2 ADC_PPB_NUMBER2
#define PFC_MTRS_SOC_PPB2 ADC_SOC_NUMBER1
#define PFC_MTRS_PPB3 ADC_PPB_NUMBER3
#define PFC_MTRS_SOC_PPB3 ADC_SOC_NUMBER3
#define PFC_MTRS_PPB4 ADC_PPB_NUMBER4
#define PFC_MTRS_SOC_PPB4 ADC_SOC_NUMBER4
void PFC_MTRS_init();


//*****************************************************************************
//
// ASYSCTL Configurations
//
//*****************************************************************************

//*****************************************************************************
//
// EPWM Configurations
//
//*****************************************************************************
#define myEPWM0_BASE EPWM1_BASE
#define myEPWM0_TBPRD 0
#define myEPWM0_COUNTER_MODE EPWM_COUNTER_MODE_STOP_FREEZE
#define myEPWM0_TBPHS 0
#define myEPWM0_CMPA 0
#define myEPWM0_CMPB 0
#define myEPWM0_CMPC 0
#define myEPWM0_CMPD 0
#define myEPWM0_DBRED 0
#define myEPWM0_DBFED 0
#define myEPWM0_TZA_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM0_TZB_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM0_INTERRUPT_SOURCE EPWM_INT_TBCTR_DISABLED

//*****************************************************************************
//
// INTERRUPT Configurations
//
//*****************************************************************************

// Interrupt Settings for INT_myADCA_1
#define INT_myADCA_1 INT_ADCC1
#define INT_myADCA_1_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP1
extern __interrupt void INT_myADCA_1_ISR(void);

// Interrupt Settings for INT_PFC_MTRS_2
#define INT_PFC_MTRS_2 INT_ADCA2
#define INT_PFC_MTRS_2_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP10
extern __interrupt void pfcCtrlISR(void);

// Interrupt Settings for INT_PFC_MTRS_3
#define INT_PFC_MTRS_3 INT_ADCA3
#define INT_PFC_MTRS_3_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP10
extern __interrupt void motor1CtrlISR(void);

// Interrupt Settings for INT_PFC_MTRS_4
#define INT_PFC_MTRS_4 INT_ADCA4
#define INT_PFC_MTRS_4_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP10
extern __interrupt void motor2CtrlISR(void);

//*****************************************************************************
//
// SYNC Scheme Configurations
//
//*****************************************************************************

//*****************************************************************************
//
// Board Configurations
//
//*****************************************************************************
void	Board_init();
void	ADC_init();
void	ASYSCTL_init();
void	EPWM_init();
void	INTERRUPT_init();
void	SYNC_init();
void	PinMux_init();

//*****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//*****************************************************************************
#ifdef __cplusplus
}
#endif

#endif  // end of BOARD_H definition
